==> nextcloud-29.0.12.tgz: nextcloud/apps/comments/l10n/ga.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Tuairimí",
    "You commented" : "Rinne tú trácht",
    "{author} commented" : "Rinne {author} nóta tráchta",
    "You commented on %1$s" : "Rinne tú trácht ar%1$s",
    "You commented on {file}" : "Rinne tú trácht ar {file}",
    "%1$s commented on %2$s" : "%1$s trácht ar %2$s",
    "{author} commented on {file}" : "{author} trácht ar {file}",
    "<strong>Comments</strong> for files" : "<strong>Tuairimí</strong> le haghaidh comhaid",
    "Files" : "Comhaid",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Luadh thú ar \"{file}\", i nóta tráchta ó chuntas a scriosadh ó shin",
    "{user} mentioned you in a comment on \"{file}\"" : "Luaigh {user} tú i nóta tráchta ar \"{file}\"",
    "Files app plugin to add comments to files" : "Breiseán aip Comhaid chun tuairimí a chur le comhaid",
    "Edit comment" : "Cuir trácht in eagar",
    "Delete comment" : "Scrios nóta tráchta",
    "Cancel edit" : "Cealaigh eagarthóireacht",
    "New comment" : "Trácht nua",
    "Write a comment …" : "Scríobh trácht…",
    "Post comment" : "Post trácht",
    "@ for mentions, : for emoji, / for smart picker" : "@ le haghaidh tagairtí, : le haghaidh emoji, / le haghaidh roghnóir cliste",
    "Could not reload comments" : "Níorbh fhéidir na nótaí tráchta a athlódáil",
    "No comments yet, start the conversation!" : "Gan trácht ar bith go fóill, cuir tús leis an gcomhrá!",
    "No more messages" : "Níl a thuilleadh teachtaireachtaí",
    "Retry" : "Bain triail eile as",
    "Failed to mark comments as read" : "Theip ar nótaí tráchta a mharcáil mar léite",
    "Unable to load the comments list" : "Ní féidir an liosta tuairimí a lódáil",
    "_1 new comment_::_{unread} new comments_" : ["1 trácht nua","{unread} nóta tráchta nua","{unread} nóta tráchta nua","{unread} nóta tráchta nua","{unread} nóta tráchta nua"],
    "Comment" : "Trácht",
    "An error occurred while trying to edit the comment" : "Tharla earráid agus an nóta tráchta á chur in eagar",
    "Comment deleted" : "Trácht scriosta",
    "An error occurred while trying to delete the comment" : "Tharla earráid agus an nóta tráchta á scriosadh",
    "An error occurred while trying to create the comment" : "Tharla earráid agus an nóta tráchta á chruthú"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/comments/l10n/ga.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Tuairimí",
    "You commented" : "Rinne tú trácht",
    "{author} commented" : "Rinne {author} nóta tráchta",
    "You commented on %1$s" : "Rinne tú trácht ar%1$s",
    "You commented on {file}" : "Rinne tú trácht ar {file}",
    "%1$s commented on %2$s" : "%1$s trácht ar %2$s",
    "{author} commented on {file}" : "{author} trácht ar {file}",
    "<strong>Comments</strong> for files" : "<strong>Tuairimí</strong> le haghaidh comhaid",
    "Files" : "Comhaid",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Luadh thú ar \"{file}\", i nóta tráchta ó chuntas a scriosadh ó shin",
    "{user} mentioned you in a comment on \"{file}\"" : "Luaigh {user} tú i nóta tráchta ar \"{file}\"",
    "Files app plugin to add comments to files" : "Breiseán aip Comhaid chun tuairimí a chur le comhaid",
    "Edit comment" : "Cuir trácht in eagar",
    "Delete comment" : "Scrios nóta tráchta",
    "Cancel edit" : "Cealaigh eagarthóireacht",
    "New comment" : "Trácht nua",
    "Write a comment …" : "Scríobh trácht…",
    "Post comment" : "Post trácht",
    "@ for mentions, : for emoji, / for smart picker" : "@ le haghaidh tagairtí, : le haghaidh emoji, / le haghaidh roghnóir cliste",
    "Could not reload comments" : "Níorbh fhéidir na nótaí tráchta a athlódáil",
    "No comments yet, start the conversation!" : "Gan trácht ar bith go fóill, cuir tús leis an gcomhrá!",
    "No more messages" : "Níl a thuilleadh teachtaireachtaí",
    "Retry" : "Bain triail eile as",
    "Failed to mark comments as read" : "Theip ar nótaí tráchta a mharcáil mar léite",
    "Unable to load the comments list" : "Ní féidir an liosta tuairimí a lódáil",
    "_1 new comment_::_{unread} new comments_" : ["1 trácht nua","{unread} nóta tráchta nua","{unread} nóta tráchta nua","{unread} nóta tráchta nua","{unread} nóta tráchta nua"],
    "Comment" : "Trácht",
    "An error occurred while trying to edit the comment" : "Tharla earráid agus an nóta tráchta á chur in eagar",
    "Comment deleted" : "Trácht scriosta",
    "An error occurred while trying to delete the comment" : "Tharla earráid agus an nóta tráchta á scriosadh",
    "An error occurred while trying to create the comment" : "Tharla earráid agus an nóta tráchta á chruthú",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Luadh thú ar \"{file}\", i nóta tráchta ó úsáideoir atá scriosta ó shin"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
